@@ -1,15 +1,12 @@
 import os
 import fire
-import sys
 import subprocess
 
 from loguru import logger as logging
-import time
-
 
 
 class Rocket:
-
+    """rocket main executable"""
     def trigger(self, project_location: str, dbfs_path: str, enable_watch=False):
         """
         :param project_location:
@@ -57,7 +54,7 @@ Great! in your notebook install the library by running:
 
 If you are running spark < 7 use this command:
 
-!pip install {self.dbfs_folder.replace("dbfs:/","/dbfs/")}/{self.wheel_file} --force-reinstall --no-deps
+%pip install {self.dbfs_folder.replace("dbfs:/","/dbfs/")}/{self.wheel_file} --force-reinstall --no-deps
 
         """
 
@@ -86,21 +83,6 @@ If you are running spark < 7 use this command:
         logging.info(f"Running shell command: {cmd} ")
         return subprocess.check_output(cmd, shell=True).decode("utf-8")
 
-    def _build_self(self):
-        """
-        Build rocket for pypi. Run it on the root of rocket project.
-        """
-        os.system("rm -rf dist/* || true")
-        os.system("python3 -m build")
-
-    def _release_self(self):
-        """
-        Build rocket for pypi. Run it on the root of rocket project.
-        """
-        os.system("rm -rf dist/* || true")
-        os.system("python3 -m build")
-        os.system("python3 -m twine upload dist/*")
-
 
 def main():
     fire.Fire(Rocket)
